JakimResponse class

Annotations
  • @freezed

Constructors

JakimResponse({required List<PrayerTime> prayerTime, required String status, required String periodType, required String lang, required String zone, required String bearing})
const
factory
JakimResponse.fromJson(Map<String, dynamic> json)
factory

Properties

bearing → String
no setterinherited
copyWith → $JakimResponseCopyWith<JakimResponse>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lang → String
no setterinherited
periodType → String
no setterinherited
prayerTime → List<PrayerTime>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
no setterinherited
zone → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited